VCardFormatter class

Constructors

VCardFormatter()

Properties

hashCode int
The hash code for this object.
no setterinherited
majorVersion int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

e(String? value) String
Encode string @param {String} value to encode @return {String} encoded string
formatVCardDate(DateTime date) String
Convert date to YYYYMMDD format @param {Date} date to encode @return {String} encoded date
getFormattedAddress({required MailingAddress address, required String encodingPrefix}) String
Get formatted address @param {Map<String, String>} address @param {String} type address type @param {String} Encoding prefix encodingPrefix @return {String} Formatted address
getFormattedPhoto(dynamic base64String) String
Get formatted photo @param {String} photoType Photo type (PHOTO, LOGO) @param {String} url URL to attach photo from @param {String} mediaType Media-type of photo (JPEG, PNG, GIF) @param {String} isBase64 Whether or not is Base64 format @return {String} Formatted photo
getFormattedString(VCard vCard) String
nl() String
Return new line characters @return {String} new line characters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited